shithub: pokered

Download patch

ref: 72bbaed99f725b2b8b0d2653968042ce1625354c
parent: 32f7cf12de9f841f76a3f2010caf6d7a80d47bcc
author: YamaArashi <shadow962@live.com>
date: Sat Feb 7 17:18:42 EST 2015

fixed hp bar wram label and misc

--- a/engine/battle/1.asm
+++ b/engine/battle/1.asm
@@ -77,7 +77,7 @@
 	hlCoord 2, 2
 	xor a
 .next2
-	ld [wListMenuID], a
+	ld [wHPBarType], a
 	predef UpdateHPBar2
 	predef DrawPlayerHUDAndHPBar
 	predef DrawEnemyHUDAndHPBar
--- a/engine/battle/4.asm
+++ b/engine/battle/4.asm
@@ -18,13 +18,14 @@
 DrawHP: ; 128ef (4:68ef)
 	call GetPredefRegisters
 	ld a, $1
-	jr asm_128fb
+	jr DrawHP_
 
-Func_128f6: ; 128f6 (4:68f6)
+DrawHP2: ; 128f6 (4:68f6)
 	call GetPredefRegisters
 	ld a, $2
-asm_128fb: ; 128fb (4:68fb)
-	ld [wListMenuID], a
+
+DrawHP_: ; 128fb (4:68fb)
+	ld [wHPBarType], a
 	push hl
 	ld a, [wLoadedMonHP]
 	ld b, a
@@ -31,14 +32,14 @@
 	ld a, [wLoadedMonHP + 1]
 	ld c, a
 	or b
-	jr nz, .asm_12913
+	jr nz, .nonzeroHP
 	xor a
 	ld c, a
 	ld e, a
 	ld a, $6
 	ld d, a
-	jp DrawHPBarAndFraction
-.asm_12913
+	jp .drawHPBarAndPrintFraction
+.nonzeroHP
 	ld a, [wLoadedMonMaxHP]
 	ld d, a
 	ld a, [wLoadedMonMaxHP + 1]
@@ -47,8 +48,7 @@
 	ld a, $6
 	ld d, a
 	ld c, a
-
-DrawHPBarAndFraction: ; 12924 (4:6924)
+.drawHPBarAndPrintFraction
 	pop hl
 	push de
 	push hl
@@ -59,10 +59,10 @@
 	bit 0, a
 	jr z, .printFractionBelowBar
 	ld bc, $9 ; right of bar
-	jr .printHPFraction
+	jr .printFraction
 .printFractionBelowBar
 	ld bc, SCREEN_WIDTH + 1 ; below bar
-.printHPFraction
+.printFraction
 	add hl, bc
 	ld de, wLoadedMonHP
 	ld bc, $203
--- a/engine/battle/4_2.asm
+++ b/engine/battle/4_2.asm
@@ -207,16 +207,16 @@
 	db $FF, $12 ;  3/256 =  1.2% chance of slot 9
 
 RecoilEffect_: ; 1392c (4:792c)
-	ld a, [H_WHOSETURN] ; $fff3
+	ld a, [H_WHOSETURN]
 	and a
-	ld a, [W_PLAYERMOVENUM] ; wcfd2
-	ld hl, wBattleMonMaxHP ; wd023
+	ld a, [W_PLAYERMOVENUM]
+	ld hl, wBattleMonMaxHP
 	jr z, .asm_1393d
-	ld a, [W_ENEMYMOVENUM] ; W_ENEMYMOVENUM
-	ld hl, wEnemyMonMaxHP ; wEnemyMonMaxHP
+	ld a, [W_ENEMYMOVENUM]
+	ld hl, wEnemyMonMaxHP
 .asm_1393d
 	ld d, a
-	ld a, [W_DAMAGE] ; W_DAMAGE
+	ld a, [W_DAMAGE]
 	ld b, a
 	ld a, [W_DAMAGE + 1]
 	ld c, a
@@ -260,7 +260,7 @@
 	ld [hl], a
 .asm_13982
 	hlCoord 10, 9
-	ld a, [H_WHOSETURN] ; $fff3
+	ld a, [H_WHOSETURN]
 	and a
 	ld a, $1
 	jr z, .asm_13990
@@ -267,9 +267,9 @@
 	hlCoord 2, 2
 	xor a
 .asm_13990
-	ld [wListMenuID], a ; wListMenuID
+	ld [wHPBarType], a
 	predef UpdateHPBar2
-	ld hl, HitWithRecoilText ; $799e
+	ld hl, HitWithRecoilText
 	jp PrintText
 HitWithRecoilText: ; 1399e (4:799e)
 	TX_FAR _HitWithRecoilText
@@ -392,8 +392,8 @@
 	ld a, [wLinkState]
 	and a
 	jr nz, .rival
-	ld hl, W_RIVALNAME ; wd34a
-	ld a, [W_TRAINERCLASS] ; wd031
+	ld hl, W_RIVALNAME
+	ld a, [W_TRAINERCLASS]
 	cp SONY1
 	jr z, .rival
 	cp SONY2
--- a/engine/battle/core.asm
+++ b/engine/battle/core.asm
@@ -768,7 +768,7 @@
 	xor a
 .playersTurn
 	push bc
-	ld [wListMenuID], a
+	ld [wHPBarType], a
 	predef UpdateHPBar2
 	pop bc
 	ret
@@ -2029,7 +2029,7 @@
 	ld c, a
 .drawHPBar
 	xor a
-	ld [wListMenuID], a
+	ld [wHPBarType], a
 	hlCoord 2, 2
 	call DrawHPBar
 	ld a, $1
@@ -4899,7 +4899,7 @@
 	ld [wHPBarNewHP],a
 	hlCoord 2, 2
 	xor a
-	ld [wListMenuID],a
+	ld [wHPBarType],a
 	predef UpdateHPBar2 ; animate the HP bar shortening
 ApplyAttackToEnemyPokemonDone: ; 3e19d (f:619d)
 	jp DrawHUDsAndHPBars
@@ -5017,7 +5017,7 @@
 	ld [wHPBarMaxHP],a
 	hlCoord 10, 9
 	ld a,$01
-	ld [wListMenuID],a
+	ld [wHPBarType],a
 	predef UpdateHPBar2 ; animate the HP bar shortening
 ApplyAttackToPlayerPokemonDone
 	jp DrawHUDsAndHPBars
--- a/engine/battle/e.asm
+++ b/engine/battle/e.asm
@@ -1174,7 +1174,7 @@
 	call AIPrintItemUse_
 	hlCoord 2, 2
 	xor a
-	ld [wListMenuID],a
+	ld [wHPBarType],a
 	predef UpdateHPBar2
 	jp DecrementAICount
 
--- a/engine/battle/e_2.asm
+++ b/engine/battle/e_2.asm
@@ -91,7 +91,7 @@
 	hlCoord 2, 2
 	xor a
 .asm_3ba83
-	ld [wListMenuID], a
+	ld [wHPBarType], a
 	predef UpdateHPBar2
 	ld hl, DrawHUDsAndHPBars
 	call BankswitchEtoF
--- a/engine/clear_save.asm
+++ b/engine/clear_save.asm
@@ -1,4 +1,4 @@
-Func_1c98a: ; 1c98a (7:498a)
+DoClearSaveDialogue: ; 1c98a (7:498a)
 	call ClearScreen
 	call GoPAL_SET_CF1C
 	call LoadFontTilePatterns
@@ -15,7 +15,7 @@
 	ld a, [wCurrentMenuItem]
 	and a
 	jp z, Init
-	callba Func_73b6a
+	callba ClearSAV
 	jp Init
 
 ClearSaveDataText: ; 1c9c1 (7:49c1)
--- a/engine/give_pokemon.asm
+++ b/engine/give_pokemon.asm
@@ -14,7 +14,7 @@
 	ld [wEnemyMonSpecies2], a
 	callab LoadEnemyMonData
 	call SetPokedexOwnedFlag
-	callab Func_e7a4
+	callab SendNewMonToBox
 	ld hl, wcf4b
 	ld a, [wd5a0]
 	and $7f
--- a/engine/hp_bar.asm
+++ b/engine/hp_bar.asm
@@ -203,7 +203,7 @@
 UpdateHPBar_PrintHPNumber: ; faf5 (3:7af5)
 	push af
 	push de
-	ld a, [wListMenuID] ; wListMenuID
+	ld a, [wHPBarType]
 	and a
 	jr z, .asm_fb2d
 	ld a, [wHPBarOldHP]
--- a/engine/items/items.asm
+++ b/engine/items/items.asm
@@ -430,7 +430,7 @@
 	jr .End
 .sendToBox	;$5907
 	call ClearSprites
-	call Func_e7a4
+	call SendNewMonToBox
 	ld hl,ItemUseBallText07
 	ld a,[wd7f1]
 	bit 0,a		;already met Bill?
@@ -923,7 +923,7 @@
 	set 0,a
 	ld [hFlags_0xFFF6],a
 	ld a,$02
-	ld [wListMenuID],a
+	ld [wHPBarType],a
 	predef UpdateHPBar2 ; animate HP bar decrease of pokemon that used Softboiled
 	ld a,[hFlags_0xFFF6]
 	res 0,a
@@ -1073,7 +1073,7 @@
 	set 0,a
 	ld [hFlags_0xFFF6],a
 	ld a,$02
-	ld [wListMenuID],a
+	ld [wHPBarType],a
 	predef UpdateHPBar2 ; animate the HP bar lengthening
 	ld a,[hFlags_0xFFF6]
 	res 0,a
@@ -1090,7 +1090,7 @@
 	jr .showHealingItemMessage
 .playStatusAilmentCuringSound
 	ld a,(SFX_02_3e - SFX_Headers_02) / 3 ; status ailment curing sound
-	call PlaySoundWaitForCurrent ; play sound
+	call PlaySoundWaitForCurrent
 .showHealingItemMessage
 	xor a
 	ld [H_AUTOBGTRANSFERENABLED],a
@@ -1102,7 +1102,7 @@
 	ld [H_AUTOBGTRANSFERENABLED],a
 	ld c,50
 	call DelayFrames
-	call WaitForTextScrollButtonPress ; wait for a button press
+	call WaitForTextScrollButtonPress
 	jr .done
 .canceledItemUse
 	xor a
@@ -1118,7 +1118,7 @@
 	ld a,[W_ISINBATTLE]
 	and a
 	ret nz
-	jp ReloadMapData ; restore saved screen
+	jp ReloadMapData
 .useVitamin
 	push hl
 	ld a,[hl]
@@ -2567,7 +2567,7 @@
 
 INCLUDE "data/key_items.asm"
 
-Func_e7a4: ; e7a4 (3:67a4)
+SendNewMonToBox: ; e7a4 (3:67a4)
 	ld de, W_NUMINBOX ; wda80
 	ld a, [de]
 	inc a
@@ -2818,15 +2818,17 @@
 	call LoadCurrentMapView
 	jp UpdateSprites
 
-Func_e9cb: ; e9cb (3:69cb)
-	ld hl, WildDataPointers ; $4eeb
-	ld de, wHPBarMaxHP
+; creates a list at wBuffer of maps where the mon in [wd11e] can be found.
+; this is used by the pokedex to display locations the mon can be found on the map.
+FindWildLocationsOfMon: ; e9cb (3:69cb)
+	ld hl, WildDataPointers
+	ld de, wBuffer
 	ld c, $0
-.asm_e9d3
+.loop
 	inc hl
 	ld a, [hld]
 	inc a
-	jr z, .asm_e9ec
+	jr z, .done
 	push hl
 	ld a, [hli]
 	ld h, [hl]
@@ -2833,34 +2835,34 @@
 	ld l, a
 	ld a, [hli]
 	and a
-	call nz, Func_e9f0
+	call nz, CheckMapForMon ; land
 	ld a, [hli]
 	and a
-	call nz, Func_e9f0
+	call nz, CheckMapForMon ; water
 	pop hl
 	inc hl
 	inc hl
 	inc c
-	jr .asm_e9d3
-.asm_e9ec
-	ld a, $ff
+	jr .loop
+.done
+	ld a, $ff ; list terminator
 	ld [de], a
 	ret
 
-Func_e9f0: ; e9f0 (3:69f0)
+CheckMapForMon: ; e9f0 (3:69f0)
 	inc hl
 	ld b, $a
-.asm_e9f3
+.loop
 	ld a, [wd11e]
 	cp [hl]
-	jr nz, .asm_e9fc
+	jr nz, .nextEntry
 	ld a, c
 	ld [de], a
 	inc de
-.asm_e9fc
+.nextEntry
 	inc hl
 	inc hl
 	dec b
-	jr nz, .asm_e9f3
+	jr nz, .loop
 	dec hl
 	ret
--- a/engine/menu/bills_pc.asm
+++ b/engine/menu/bills_pc.asm
@@ -1,6 +1,6 @@
 Func_213c8:: ; 213c8 (8:53c8)
 	xor a
-	ld [H_AUTOBGTRANSFERENABLED], a ; $ffba
+	ld [H_AUTOBGTRANSFERENABLED], a
 	call SaveScreenTilesToBuffer2
 	ld a, [wd5a2]
 	and a
@@ -28,64 +28,64 @@
 	call TextBoxBorder
 	call UpdateSprites
 	ld a, $3
-	ld [wMaxMenuItem], a ; wMaxMenuItem
+	ld [wMaxMenuItem], a
 	ld a, [wd7f1]
 	bit 0, a
 	jr nz, .asm_21414
 	hlCoord 2, 2
-	ld de, SomeonesPCText ; $548b
+	ld de, SomeonesPCText
 	jr .asm_2141a
 .asm_21414
 	hlCoord 2, 2
-	ld de, BillsPCText ; $5497
+	ld de, BillsPCText
 .asm_2141a
 	call PlaceString
 	hlCoord 2, 4
-	ld de, wPlayerName ; wd158
+	ld de, wPlayerName
 	call PlaceString
 	ld l, c
 	ld h, b
-	ld de, PlayersPCText ; $54a0
+	ld de, PlayersPCText
 	call PlaceString
 	ld a, [wd74b]
 	bit 5, a
 	jr z, .asm_21462
 	hlCoord 2, 6
-	ld de, OaksPCText ; $54a5
+	ld de, OaksPCText
 	call PlaceString
 	ld a, [wd5a2]
 	and a
 	jr z, .asm_2145a
 	ld a, $4
-	ld [wMaxMenuItem], a ; wMaxMenuItem
+	ld [wMaxMenuItem], a
 	hlCoord 2, 8
-	ld de, PKMNLeaguePCText ; $54b2
+	ld de, PKMNLeaguePCText
 	call PlaceString
 	hlCoord 2, 10
-	ld de, LogOffPCText ; $54ba
+	ld de, LogOffPCText
 	jr .asm_2146d
 .asm_2145a
 	hlCoord 2, 8
-	ld de, LogOffPCText ; $54ba
+	ld de, LogOffPCText
 	jr .asm_2146d
 .asm_21462
 	ld a, $2
-	ld [wMaxMenuItem], a ; wMaxMenuItem
+	ld [wMaxMenuItem], a
 	hlCoord 2, 6
-	ld de, LogOffPCText ; $54ba
+	ld de, LogOffPCText
 .asm_2146d
 	call PlaceString
 	ld a, $3
-	ld [wMenuWatchedKeys], a ; wMenuWatchedKeys
+	ld [wMenuWatchedKeys], a
 	ld a, $2
-	ld [wTopMenuItemY], a ; wTopMenuItemY
+	ld [wTopMenuItemY], a
 	ld a, $1
-	ld [wTopMenuItemX], a ; wTopMenuItemX
+	ld [wTopMenuItemX], a
 	xor a
-	ld [wCurrentMenuItem], a ; wCurrentMenuItem
-	ld [wLastMenuItem], a ; wLastMenuItem
+	ld [wCurrentMenuItem], a
+	ld [wLastMenuItem], a
 	ld a, $1
-	ld [H_AUTOBGTRANSFERENABLED], a ; $ffba
+	ld [H_AUTOBGTRANSFERENABLED], a
 	ret
 
 SomeonesPCText:   db "SOMEONE's PC@"
@@ -103,7 +103,7 @@
 	inc a               ; MONSTER_NAME
 	ld [W_LISTTYPE], a
 	call LoadHpBarAndStatusTilePatterns
-	ld a, [wListScrollOffset] ; wcc36
+	ld a, [wListScrollOffset]
 	push af
 	ld a, [wFlags_0xcd60]
 	bit 3, a
@@ -116,9 +116,9 @@
 Func_214e8: ; 214e8 (8:54e8)
 BillsPCMenu:
 	ld a, [wccd3]
-	ld [wCurrentMenuItem], a ; wCurrentMenuItem
+	ld [wCurrentMenuItem], a
 	ld hl, vChars2 + $780
-	ld de, PokeballTileGraphics ; $697e
+	ld de, PokeballTileGraphics
 	ld bc, (BANK(PokeballTileGraphics) << 8) + $01
 	call CopyVideoData
 	call LoadScreenTilesFromBuffer2DisableBGTransfer
@@ -127,9 +127,9 @@
 	ld c, $c
 	call TextBoxBorder
 	hlCoord 2, 2
-	ld de, BillsPCMenuText ; $56e1
+	ld de, BillsPCMenuText
 	call PlaceString
-	ld hl, wTopMenuItemY ; wTopMenuItemY
+	ld hl, wTopMenuItemY
 	ld a, $2
 	ld [hli], a
 	dec a
@@ -143,10 +143,10 @@
 	xor a
 	ld [hli], a
 	ld [hli], a
-	ld hl, wListScrollOffset ; wcc36
+	ld hl, wListScrollOffset
 	ld [hli], a
 	ld [hl], a
-	ld [wPlayerMonNumber], a ; wPlayerMonNumber
+	ld [wPlayerMonNumber], a
 	ld hl, WhatText
 	call PrintText
 	hlCoord 9, 14
@@ -167,16 +167,16 @@
 .asm_21551
 	Coorda 18, 16
 	hlCoord 10, 16
-	ld de, BoxNoPCText ; $5713
+	ld de, BoxNoPCText
 	call PlaceString
 	ld a, $1
-	ld [H_AUTOBGTRANSFERENABLED], a ; $ffba
+	ld [H_AUTOBGTRANSFERENABLED], a
 	call Delay3
 	call HandleMenuInput
 	bit 1, a
 	jp nz, Func_21588 ; b button
 	call PlaceUnfilledArrowMenuCursor
-	ld a, [wCurrentMenuItem] ; wCurrentMenuItem
+	ld a, [wCurrentMenuItem]
 	ld [wccd3], a
 	and a
 	jp z, Func_21618 ; withdraw
@@ -200,7 +200,7 @@
 	res 5, [hl]
 	call LoadScreenTilesFromBuffer2
 	pop af
-	ld [wListScrollOffset], a ; wcc36
+	ld [wListScrollOffset], a
 	ld hl, wd730
 	res 6, [hl]
 	ret
@@ -207,7 +207,7 @@
 
 Func_215ac: ; 215ac (8:55ac)
 BillsPCDeposit:
-	ld a, [wPartyCount] ; wPartyCount
+	ld a, [wPartyCount]
 	dec a
 	jr nz, .asm_215bb
 	ld hl, CantDepositLastMonText
@@ -214,14 +214,14 @@
 	call PrintText
 	jp BillsPCMenu
 .asm_215bb
-	ld a, [W_NUMINBOX] ; wda80
+	ld a, [W_NUMINBOX]
 	cp MONS_PER_BOX
 	jr nz, .asm_215cb
-	ld hl, BoxFullText ; $5802
+	ld hl, BoxFullText
 	call PrintText
 	jp BillsPCMenu
 .asm_215cb
-	ld hl, wPartyCount ; wPartyCount
+	ld hl, wPartyCount
 	call Func_216be
 	jp c, BillsPCMenu
 	call Func_2174b
@@ -236,7 +236,7 @@
 	ld [wcf95], a
 	call RemovePokemon
 	call WaitForSoundToFinish
-	ld hl, wWhichTrade ; wWhichTrade
+	ld hl, wWhichTrade
 	ld a, [wd5a0]
 	and $7f
 	cp 9
@@ -251,31 +251,31 @@
 .asm_2160c
 	ld [hli], a
 	ld [hl], $50
-	ld hl, MonWasStoredText ; $57f8
+	ld hl, MonWasStoredText
 	call PrintText
 	jp BillsPCMenu
 
 Func_21618: ; 21618 (8:5618)
-	ld a, [W_NUMINBOX] ; wda80
+	ld a, [W_NUMINBOX]
 	and a
 	jr nz, .asm_21627
-	ld hl, NoMonText ; $580c
+	ld hl, NoMonText
 	call PrintText
 	jp Func_214e8
 .asm_21627
-	ld a, [wPartyCount] ; wPartyCount
+	ld a, [wPartyCount]
 	cp PARTY_LENGTH
 	jr nz, .asm_21637
-	ld hl, CantTakeMonText ; $5811
+	ld hl, CantTakeMonText
 	call PrintText
 	jp Func_214e8
 .asm_21637
-	ld hl, W_NUMINBOX ; wda80
+	ld hl, W_NUMINBOX
 	call Func_216be
 	jp c, Func_214e8
 	call Func_2174b
 	jp nc, Func_214e8
-	ld a, [wWhichPokemon] ; wWhichPokemon
+	ld a, [wWhichPokemon]
 	ld hl, wBoxMonNicks
 	call GetPartyMonName
 	ld a, [wcf91]
@@ -288,25 +288,25 @@
 	ld [wcf95], a
 	call RemovePokemon
 	call WaitForSoundToFinish
-	ld hl, MonIsTakenOutText ; $5807
+	ld hl, MonIsTakenOutText
 	call PrintText
 	jp Func_214e8
 
 Func_21673: ; 21673 (8:5673)
-	ld a, [W_NUMINBOX] ; wda80
+	ld a, [W_NUMINBOX]
 	and a
 	jr nz, .asm_21682
-	ld hl, NoMonText ; $580c
+	ld hl, NoMonText
 	call PrintText
 	jp Func_214e8
 .asm_21682
-	ld hl, W_NUMINBOX ; wda80
+	ld hl, W_NUMINBOX
 	call Func_216be
 	jp c, Func_214e8
-	ld hl, OnceReleasedText ; $581b
+	ld hl, OnceReleasedText
 	call PrintText
 	call YesNoChoice
-	ld a, [wCurrentMenuItem] ; wCurrentMenuItem
+	ld a, [wCurrentMenuItem]
 	and a
 	jr nz, .asm_21682
 	inc a
@@ -315,7 +315,7 @@
 	call WaitForSoundToFinish
 	ld a, [wcf91]
 	call PlayCry
-	ld hl, MonWasReleasedText ; $5820
+	ld hl, MonWasReleasedText
 	call PrintText
 	jp Func_214e8
 
@@ -330,13 +330,13 @@
 	ld [wList + 1], a
 	xor a
 	ld [wcf93], a
-	ld [wListMenuID], a ; wListMenuID
+	ld [wListMenuID], a
 	inc a                ; MONSTER_NAME
 	ld [W_LISTTYPE], a
 	ld a, [wcc2b]
-	ld [wCurrentMenuItem], a ; wCurrentMenuItem
+	ld [wCurrentMenuItem], a
 	call DisplayListMenuID
-	ld a, [wCurrentMenuItem] ; wCurrentMenuItem
+	ld a, [wCurrentMenuItem]
 	ld [wcc2b], a
 	ret
 
@@ -368,7 +368,7 @@
 	ld a, [hli]
 	push hl
 	push bc
-	ld hl, HMMoveArray ; $5745
+	ld hl, HMMoveArray
 	ld de, 1
 	call IsInArray
 	pop bc
@@ -394,16 +394,16 @@
 	call TextBoxBorder
 	ld a, [wccd3]
 	and a
-	ld de, DepositPCText ; $57cb
+	ld de, DepositPCText
 	jr nz, .asm_21761
-	ld de, WithdrawPCText ; $57d3
+	ld de, WithdrawPCText
 .asm_21761
 	hlCoord 11, 12
 	call PlaceString
 	hlCoord 11, 14
-	ld de, StatsCancelPCText ; $57dc
+	ld de, StatsCancelPCText
 	call PlaceString
-	ld hl, wTopMenuItemY ; wTopMenuItemY
+	ld hl, wTopMenuItemY
 	ld a, $c
 	ld [hli], a
 	ld a, $a
@@ -417,16 +417,16 @@
 	ld [hli], a
 	xor a
 	ld [hl], a
-	ld hl, wListScrollOffset ; wcc36
+	ld hl, wListScrollOffset
 	ld [hli], a
 	ld [hl], a
-	ld [wPlayerMonNumber], a ; wPlayerMonNumber
+	ld [wPlayerMonNumber], a
 	ld [wcc2b], a
 .asm_2178f
 	call HandleMenuInput
 	bit 1, a
 	jr nz, .asm_2179f
-	ld a, [wCurrentMenuItem] ; wCurrentMenuItem
+	ld a, [wCurrentMenuItem]
 	and a
 	jr z, .asm_217a1
 	dec a
--- a/engine/menu/party_menu.asm
+++ b/engine/menu/party_menu.asm
@@ -92,7 +92,7 @@
 	set 0,a
 	ld [hFlags_0xFFF6],a
 	add hl,bc
-	predef Func_128f6 ; draw HP bar and prints current / max HP
+	predef DrawHP2 ; draw HP bar and prints current / max HP
 	ld a,[hFlags_0xFFF6]
 	res 0,a
 	ld [hFlags_0xFFF6],a
--- a/engine/menu/players_pc.asm
+++ b/engine/menu/players_pc.asm
@@ -17,7 +17,7 @@
 
 Func_790c: ; 790c (1:790c)
 	ld a, [wccd3]
-	ld [wCurrentMenuItem], a ; wCurrentMenuItem
+	ld [wCurrentMenuItem], a
 	ld hl, wFlags_0xcd60
 	set 5, [hl]
 	call LoadScreenTilesFromBuffer2
@@ -27,9 +27,9 @@
 	call TextBoxBorder
 	call UpdateSprites
 	hlCoord 2, 2
-	ld de, PlayersPCMenuEntries ; $7af5
+	ld de, PlayersPCMenuEntries
 	call PlaceString
-	ld hl, wTopMenuItemY ; wTopMenuItemY
+	ld hl, wTopMenuItemY
 	ld a, $2
 	ld [hli], a
 	dec a
@@ -42,10 +42,10 @@
 	ld [hli], a
 	xor a
 	ld [hl], a
-	ld hl, wListScrollOffset ; wcc36
+	ld hl, wListScrollOffset
 	ld [hli], a
 	ld [hl], a
-	ld [wPlayerMonNumber], a ; wPlayerMonNumber
+	ld [wPlayerMonNumber], a
 	ld hl, WhatDoYouWantText
 	call PrintText
 	call HandleMenuInput
@@ -52,7 +52,7 @@
 	bit 1, a
 	jp nz, Func_796d
 	call PlaceUnfilledArrowMenuCursor
-	ld a, [wCurrentMenuItem] ; wCurrentMenuItem
+	ld a, [wCurrentMenuItem]
 	ld [wccd3], a
 	and a
 	jp z, Func_7a12
@@ -73,7 +73,7 @@
 	res 5, [hl]
 	call LoadScreenTilesFromBuffer2
 	xor a
-	ld [wListScrollOffset], a ; wcc36
+	ld [wListScrollOffset], a
 	ld [wcc2c], a
 	ld hl, wd730
 	res 6, [hl]
@@ -83,9 +83,9 @@
 
 Func_7995: ; 7995 (1:7995)
 	xor a
-	ld [wCurrentMenuItem], a ; wCurrentMenuItem
-	ld [wListScrollOffset], a ; wcc36
-	ld a, [wNumBagItems] ; wNumBagItems
+	ld [wCurrentMenuItem], a
+	ld [wListScrollOffset], a
+	ld a, [wNumBagItems]
 	and a
 	jr nz, Func_79ab
 	ld hl, NothingToDepositText
@@ -95,7 +95,7 @@
 Func_79ab: ; 79ab (1:79ab)
 	ld hl, WhatToDepositText
 	call PrintText
-	ld hl, wNumBagItems ; wNumBagItems
+	ld hl, wNumBagItems
 	ld a, l
 	ld [wList], a
 	ld a, h
@@ -103,7 +103,7 @@
 	xor a
 	ld [wcf93], a
 	ld a, $3
-	ld [wListMenuID], a ; wListMenuID
+	ld [wListMenuID], a
 	call DisplayListMenuID
 	jp c, Func_790c
 	call IsKeyItem
@@ -118,7 +118,7 @@
 	cp $ff
 	jp z, Func_79ab
 .asm_79e7
-	ld hl, wNumBoxItems ; wNumBoxItems
+	ld hl, wNumBoxItems
 	call AddItemToInventory
 	jr c, .asm_79f8
 	ld hl, NoRoomToStoreText
@@ -125,7 +125,7 @@
 	call PrintText
 	jp Func_79ab
 .asm_79f8
-	ld hl, wNumBagItems ; wNumBagItems
+	ld hl, wNumBagItems
 	call RemoveItemFromInventory
 	call WaitForSoundToFinish
 	ld a, (SFX_02_55 - SFX_Headers_02) / 3
@@ -137,9 +137,9 @@
 
 Func_7a12: ; 7a12 (1:7a12)
 	xor a
-	ld [wCurrentMenuItem], a ; wCurrentMenuItem
-	ld [wListScrollOffset], a ; wcc36
-	ld a, [wNumBoxItems] ; wNumBoxItems
+	ld [wCurrentMenuItem], a
+	ld [wListScrollOffset], a
+	ld a, [wNumBoxItems]
 	and a
 	jr nz, Func_7a28
 	ld hl, NothingStoredText
@@ -149,7 +149,7 @@
 Func_7a28: ; 7a28 (1:7a28)
 	ld hl, WhatToWithdrawText
 	call PrintText
-	ld hl, wNumBoxItems ; wNumBoxItems
+	ld hl, wNumBoxItems
 	ld a, l
 	ld [wList], a
 	ld a, h
@@ -157,7 +157,7 @@
 	xor a
 	ld [wcf93], a
 	ld a, $3
-	ld [wListMenuID], a ; wListMenuID
+	ld [wListMenuID], a
 	call DisplayListMenuID
 	jp c, Func_790c
 	call IsKeyItem
@@ -172,7 +172,7 @@
 	cp $ff
 	jp z, Func_7a28
 .asm_7a64
-	ld hl, wNumBagItems ; wNumBagItems
+	ld hl, wNumBagItems
 	call AddItemToInventory
 	jr c, .asm_7a75
 	ld hl, CantCarryMoreText
@@ -179,7 +179,7 @@
 	call PrintText
 	jp Func_7a28
 .asm_7a75
-	ld hl, wNumBoxItems ; wNumBoxItems
+	ld hl, wNumBoxItems
 	call RemoveItemFromInventory
 	call WaitForSoundToFinish
 	ld a, (SFX_02_55 - SFX_Headers_02) / 3
@@ -191,9 +191,9 @@
 
 Func_7a8f: ; 7a8f (1:7a8f)
 	xor a
-	ld [wCurrentMenuItem], a ; wCurrentMenuItem
-	ld [wListScrollOffset], a ; wcc36
-	ld a, [wNumBoxItems] ; wNumBoxItems
+	ld [wCurrentMenuItem], a
+	ld [wListScrollOffset], a
+	ld a, [wNumBoxItems]
 	and a
 	jr nz, Func_7aa5
 	ld hl, NothingStoredText
@@ -203,7 +203,7 @@
 Func_7aa5: ; 7aa5 (1:7aa5)
 	ld hl, WhatToTossText
 	call PrintText
-	ld hl, wNumBoxItems ; wNumBoxItems
+	ld hl, wNumBoxItems
 	ld a, l
 	ld [wList], a
 	ld a, h
@@ -211,7 +211,7 @@
 	xor a
 	ld [wcf93], a
 	ld a, $3
-	ld [wListMenuID], a ; wListMenuID
+	ld [wListMenuID], a
 	push hl
 	call DisplayListMenuID
 	pop hl
--- a/engine/menu/status_screen.asm
+++ b/engine/menu/status_screen.asm
@@ -55,7 +55,7 @@
 	ld de, Type1Text
 	call PlaceString ; "TYPE1/"
 	hlCoord 11, 3
-	predef DrawHP ; predef $5f
+	predef DrawHP
 	ld hl, wcf25
 	call GetHealthBarColor
 	ld b, $3
--- a/engine/predefs.asm
+++ b/engine/predefs.asm
@@ -148,6 +148,6 @@
 	add_predef PrintMoveType
 	add_predef LoadMovePPs
 	add_predef DrawHP ; 5F
-	add_predef Func_128f6
+	add_predef DrawHP2
 	add_predef Func_1c9c6
 	add_predef OaksAideScript
--- a/engine/predefs7.asm
+++ b/engine/predefs7.asm
@@ -6,23 +6,23 @@
 	ld [wList], a
 	ld a, h
 	ld [wList + 1], a
-	ld a, [wListScrollOffset] ; wcc36
+	ld a, [wListScrollOffset]
 	push af
 	xor a
-	ld [wCurrentMenuItem], a ; wCurrentMenuItem
-	ld [wListScrollOffset], a ; wcc36
+	ld [wCurrentMenuItem], a
+	ld [wListScrollOffset], a
 	ld [wcf93], a
 	ld a, $4
-	ld [wListMenuID], a ; wListMenuID
+	ld [wListMenuID], a
 	call DisplayListMenuID
 	pop bc
 	ld a, b
-	ld [wListScrollOffset], a ; wcc36
+	ld [wListScrollOffset], a
 	ret c
 	ld hl, wd126
 	set 7, [hl]
 	ld hl, wcc5b
-	ld a, [wWhichPokemon] ; wWhichPokemon
+	ld a, [wWhichPokemon]
 	add a
 	ld d, $0
 	ld e, a
--- a/engine/save.asm
+++ b/engine/save.asm
@@ -665,7 +665,7 @@
 	ld [MBC1SRamEnable], a
 	ret
 
-Func_73b6a: ; 73b6a (1c:7b6a)
+ClearSAV: ; 73b6a (1c:7b6a)
 	ld a, SRAM_ENABLE
 	ld [MBC1SRamEnable], a
 	ld a, $1
--- a/engine/titlescreen.asm
+++ b/engine/titlescreen.asm
@@ -237,14 +237,14 @@
 	call LoadGBPal
 	ld a, [hJoyHeld]
 	ld b, a
-	and $46
-	cp $46
-	jp z, Func_448e
+	and D_UP | SELECT | B_BUTTON
+	cp D_UP | SELECT | B_BUTTON
+	jp z, .doClearSaveDialogue
 	jp MainMenu
 
-Func_448e: ; 448e (1:448e)
-	ld b, BANK(Func_1c98a)
-	ld hl, Func_1c98a
+.doClearSaveDialogue
+	ld b, BANK(DoClearSaveDialogue)
+	ld hl, DoClearSaveDialogue
 	jp Bankswitch
 
 Func_4496: ; 4496 (1:4496)
--- a/engine/town_map.asm
+++ b/engine/town_map.asm
@@ -364,10 +364,10 @@
 	jp CopyData
 
 Func_711ef: ; 711ef (1c:51ef)
-	callba Func_e9cb
+	callba FindWildLocationsOfMon
 	call Func_712d9
 	ld hl, wOAMBuffer
-	ld de, wHPBarMaxHP
+	ld de, wBuffer
 .asm_71200
 	ld a, [de]
 	cp $ff
--- a/wram.asm
+++ b/wram.asm
@@ -803,6 +803,12 @@
 
 wcf93:: ds 1
 
+wHPBarType:: ; cf94
+; type of HP bar
+; $00 = enemy HUD in battle
+; $01 = player HUD in battle / status screen
+; $02 = party menu
+
 wListMenuID:: ; cf94
 ; ID used by DisplayListMenuID
 	ds 1
--- a/home.asm
+++ b/home.asm
@@ -173,7 +173,7 @@
 DrawHPBar:: ; 1336 (0:1336)
 ; Draw an HP bar d tiles long, and fill it to e pixels.
 ; If c is nonzero, show at least a sliver regardless.
 ; The right end of the bar changes with [wListMenuID].
 
 	push hl
 	push de
@@ -195,7 +195,7 @@
 	jr nz, .draw
 
 	; Right
-	ld a,[wListMenuID]
+	ld a,[wHPBarType]
 	dec a
 	ld a, $6d ; status screen and battle
 	jr z, .ok
@@ -173,7 +173,7 @@
 ; Draw an HP bar d tiles long, and fill it to e pixels.
 ; If c is nonzero, show at least a sliver regardless.
-; The right end of the bar changes with [wListMenuID].
+; The right end of the bar changes with [wHPBarType].
 
 	push hl